@@ -1,6 +1,6 @@
 import cv2
 
-from imaginairy.img_utils import pillow_img_to_opencv_img
+from classy_imaginary.img_utils import pillow_img_to_opencv_img
 
 
 def calculate_blurriness_level(img):
